@@ -5,28 +5,19 @@ use 5.008001;
 use strict;
 use warnings;
 
-# OK, the following is probably paranoia. But if Perl 7 decides to
-# change this particular default I'm ready. Unless they eliminate $].
-no if $] ge '5.020', feature => qw{ signatures };
-
 use Carp;
 use Exporter 5.567;	# Comes with Perl 5.8.1.
-# use File::Find ();
-# use File::Spec ();
-# use Getopt::Long 2.34;	# Comes with Perl 5.8.1.
-use Test2::API 1.302096 ();
-use Test2::API::Context 1.302096 ();	# for pass_and_release().
-use Test2::Util 1.302096 ();
+use Getopt::Long 2.34;	# Comes with Perl 5.8.1.
+use Test2::API ();
+use Test2::Util ();
 
 use base qw{ Exporter };
 
-our $VERSION = '0.008_01';
+our $VERSION = '0.001';
 $VERSION =~ s/ _ //smxg;
 
 {
     my @test2 = qw{
-	all_modules_tried_ok
-	clear_modules_tried
 	load_module_ok
 	load_module_or_skip
 	load_module_or_skip_all
@@ -101,67 +92,16 @@ use constant TEST_MORE_OPT		=> {
     require	=> 1,
 };
 
-{
-    my %module_tried;
+sub load_module_ok (@) {	## no critic (RequireArgUnpacking)
+    my @arg = _validate_args( 0, @_ );
 
-    sub load_module_ok (@) {	## no critic (RequireArgUnpacking)
-	my @arg = _validate_args( 0, @_ );
+    my $ctx = Test2::API::context();
 
-	# We do this now in case _load_module_ok() throws an uncaught
-	# exception, just so we have SOME record we tried.
-	$module_tried{ $arg[1] } = undef;
+    my $rslt = _load_module_ok( @arg );
 
-	my $ctx = Test2::API::context();
+    $ctx->release();
 
-	my $rslt = _load_module_ok( @arg );
-
-	$module_tried{ $arg[1] } = $rslt;
-
-	$ctx->release();
-
-	return $rslt;
-    }
-
-    sub all_modules_tried_ok (@) {
-	my @where = @_;
-	@where
-	    or @where = ( 'blib/lib', 'blib/arch' );
-
-	require File::Find;
-	require File::Spec;
-
-	my @not_tried;
-	foreach my $d ( @where ) {
-	    File::Find::find( sub {
-		    m/ [.] pm \z /smx
-			or return;
-		    my ( undef, $dir, $name ) = File::Spec->splitpath(
-			File::Spec->abs2rel( $File::Find::name, $d ) );
-		    my @dir = File::Spec->splitdir( $dir );
-		    $dir[-1]
-			or pop @dir;
-		    ( my $module = join '::', @dir, $name ) =~ s/ [.] pm //smx;
-		    exists $module_tried{$module}
-			or push @not_tried, $module;
-		}, $d );
-	}
-
-	if ( @not_tried ) {
-
-	    my $ctx = Test2::API::context();
-
-	    $ctx->fail( "Module $_ not tried" ) for sort @not_tried;
-
-	    $ctx->release();
-
-	    return 0;
-	}
-    }
-
-    sub clear_modules_tried () {
-	%module_tried = ();
-	return;
-    }
+    return $rslt;
 }
 
 sub _load_module_ok {
@@ -187,6 +127,7 @@ sub _load_module_ok {
     return $ctx->fail_and_release( $name, @diag );
 }
 
+
 sub load_module_or_skip (@) {	## no critic (RequireArgUnpacking,RequireFinalReturn)
     my ( $opt, $module, $version, $import, $name, $num ) = _validate_args( 5, @_ );
 
@@ -226,6 +167,7 @@ sub load_module_or_skip_all (@) {	## no critic (RequireArgUnpacking)
     return;
 }
 
+
 sub _load_module {
     my ( $opt, $module, $version, $import ) = @_;
 
@@ -237,7 +179,8 @@ sub _load_module {
 }
 
 {
-    my $psr;
+    my $psr = Getopt::Long::Parser->new();
+    $psr->configure( qw{ posix_default } );
 
     # Because we want to work with Perl 5.8.1 we are limited to
     # Getopt::Long 2.34, and therefore getoptions(). So we expect the
@@ -249,13 +192,6 @@ sub _load_module {
 	my ( $opt ) = @_;
 	$opt ||= {};
 	{
-	    unless ( $psr ) {
-		require Getopt::Long;
-		Getopt::Long->VERSION( 2.34 );
-		$psr = Getopt::Long::Parser->new();
-		$psr->configure( qw{ posix_default } );
-	    }
-
 	    my $opt_err;
 	    local $SIG{__WARN__} = sub { $opt_err = $_[0] };
 	    $psr->getoptions( $opt, qw{
@@ -359,6 +295,7 @@ sub _caller_class {
     }
 }
 
+
 sub __build_load_eval {
     my @arg = @_;
     HASH_REF eq ref $arg[0]
@@ -380,6 +317,7 @@ sub __build_load_eval {
     return "@eval;";
 }
 
+
 sub _validate_args {
     ( my $max_arg, local @ARGV ) = @_;
     my $opt = _parse_opts( __get_hint_hash( 2 ) );
@@ -425,6 +363,7 @@ EOD
     return $rslt;
 }
 
+
 sub _get_call_info {
     my $lvl = 0;
     while ( my @info = caller $lvl++ ) {
@@ -436,6 +375,7 @@ sub _get_call_info {
     confess 'Bug - Unable to determine caller';
 }
 
+
 1;
 
 __END__
@@ -484,28 +424,6 @@ fixed it for my own use by initializing the testing system as late as
 possible, but I can not promise that all such problems have been
 eliminated.
 
-=head1 CAVEAT
-
-Accurately testing whether a module can be loaded is more complicated
-than it might first appear. One known issue is that you can get a false
-pass if the module under test forgets to load a module it needs, but
-this module loads it for its own use.
-
-Ideally this module would use nothing that C<Test2> does not, but that
-seems to require a fair amount of wheel-reinventing. What this module
-does try to do is to load the extra modules only if it really needs
-them. Specifically:
-
-L<Getopt::Long|Getopt::Long> is loaded only if arguments are passed to
-the C<use Test::Tools::LoadModule> statement.
-
-L<File::Find|File::Find> and L<File::Spec|File::Spec> are loaded only if
-L<all_modules_tried_ok()|/all_modules_tried_ok> is called.
-
-Because L<Carp|Carp> and L<Exporter|Exporter> are used by
-L<Test2::API|Test2::API> (at least as of version C<1.302181>), this
-module makes no attempt to avoid their use.
-
 =head1 SUBROUTINES
 
 All subroutines documented below are exportable, either by name or using
@@ -585,10 +503,6 @@ By default, C<$@> is appended to the diagnostics issued in the event of
 a load failure. If you want to omit this, or embed the value in your own
 text, see L<CONFIGURATION|/CONFIGURATION>, below.
 
-As a side effect, the names of all modules tried with this test are
-recorded, along with test results (pass/fail) for the use of
-L<all_modules_tried_ok()|/all_modules_tried_ok>.
-
 =head2 load_module_or_skip
 
  load_module_or_skip $module, $ver, $import, $name, $num;
@@ -628,39 +542,6 @@ This subroutine can be called either at the top level or in a subtest,
 but either way it B<must> be called before any actual tests in the file
 or subtest.
 
-=head2 all_modules_tried_ok
-
- all_modules_tried_ok
-
-Added in version C<0.002>.
-
-Prototype: C<(@)>.
-
-This test traverses any directories specified as arguments looking for
-Perl modules (defined as files whose names end in F<.pm>). A failing
-test is generated for any such file not previously tested using
-L<load_module_ok()|/load_module_ok>.
-
-If no directory is specified, the default is
-C< ( '/blib/lib', '/blib/arch' ) >.
-
-B<NOTE> that no attempt is made to parse the file and determine its
-module name. The module is assumed from the part of the file path below
-the specified directory. So an explicit specification of F<lib/> will
-work (if that is where the modules are stored) but an explicit F<blib/>
-will not.
-
-=head2 clear_modules_tried
-
- clear_modules_tried
-
-Added in version C<0.002>.
-
-Prototype: C<()>.
-
-This is not a test. It clears the record of modules tried by
-L<load_module_ok()|/load_module_ok>.
-
 =head2 require_ok
 
  require_ok $module;
@@ -767,9 +648,6 @@ L<Test::More|Test::More>
 
 L<Test2::V0|Test2::V0>
 
-L<Test2::Require|Test2::Require>, especially
-L<Test2::Require::Module|Test2::Require::Module>.
-
 L<Test2::Manual::Testing::Migrating|Test2::Manual::Testing::Migrating>
 
 L<Test2::Plugin::BailOnFail|Test2::Plugin::BailOnFail>
@@ -777,9 +655,7 @@ L<Test2::Plugin::BailOnFail|Test2::Plugin::BailOnFail>
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=Test2-Tools-LoadModule>,
-L<https://github.com/trwyant/perl-Test2-Tools-LoadModule/issues>, or in
-electronic mail to the author.
+L<https://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -787,11 +663,11 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2019-2025 by Thomas R. Wyant, III
+Copyright (C) 2019-2020 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
-of the licenses in the files F<LICENSE-Artistic> and F<LICENSE-GPL>.
+of the licenses in the directory LICENSES.
 
 This program is distributed in the hope that it will be useful, but
 without any warranty; without even the implied warranty of
