@@ -8,7 +8,7 @@ use warnings;
 use Carp;
 use Exporter qw{ import };
 
-our $VERSION = '0.008_01';
+our $VERSION = '0.001';
 $VERSION =~ s/ _ //smxg;
 
 our @EXPORT = qw{ and_accounted_for };
@@ -52,9 +52,7 @@ exported by default.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=Test2-Tools-LoadModule>,
-L<https://github.com/trwyant/perl-Test2-Tools-LoadModule/issues>, or in
-electronic mail to the author.
+L<https://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -62,11 +60,11 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2020-2025 by Thomas R. Wyant, III
+Copyright (C) 2020 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
-of the licenses in the files F<LICENSE-Artistic> and F<LICENSE-GPL>.
+of the licenses in the directory LICENSES.
 
 This program is distributed in the hope that it will be useful, but
 without any warranty; without even the implied warranty of
